'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _extends = require('./extends-dcc897fe.js');
var _styled = require('styled-components');
var React = require('react');
var index = require('./index-daca4eba.js');
var ButtonBase = require('./ButtonBase.js');
var environment = require('./environment.js');
var Theme = require('./Theme.js');
var css = require('./css.js');
var textStyles = require('./text-styles.js');
var constants = require('./constants.js');
require('./FocusVisible.js');
require('./defineProperty-74f274e0.js');
require('./keycodes.js');
require('./miscellaneous.js');
require('./theme-dark.js');
require('./theme-light.js');
require('./color.js');
require('./font.js');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var _styled__default = /*#__PURE__*/_interopDefaultLegacy(_styled);
var React__default = /*#__PURE__*/_interopDefaultLegacy(React);

// See src/icons/icon-size.js for the corresponding icon sizes.

const SIZE_STYLES = {
  medium: {
    textStyleName: 'body3',
    height: 5 * constants.GU,
    padding: 3 * constants.GU,
    iconPadding: 2 * constants.GU,
    minWidth: 14.5 * constants.GU,
    middleSpace: 1 * constants.GU
  },
  small: {
    textStyleName: 'body3',
    height: 4 * constants.GU,
    padding: 2 * constants.GU,
    iconPadding: 1.5 * constants.GU,
    minWidth: 13 * constants.GU,
    middleSpace: 1 * constants.GU
  },
  mini: {
    textStyleName: 'body3',
    height: 3 * constants.GU,
    padding: 1.5 * constants.GU,
    iconPadding: 1 * constants.GU,
    minWidth: 9.25 * constants.GU,
    middleSpace: 0.5 * constants.GU
  }
};

function getPadding(size, displayIcon, displayLabel) {
  const {
    padding,
    iconPadding
  } = SIZE_STYLES[size];

  if (displayIcon && !displayLabel) {
    return '0';
  }

  if (displayIcon && displayLabel) {
    return `0 ${padding}px 0 ${iconPadding}px`;
  }

  return `0 ${padding}px`;
}

function getWidth(size, displayIconOnly, wide) {
  const {
    height
  } = SIZE_STYLES[size];

  if (wide) {
    return '100%';
  }

  if (displayIconOnly) {
    return `${height}px`;
  }

  return 'auto';
}

function getMinWidth(size, displayLabelOnly) {
  const {
    minWidth
  } = SIZE_STYLES[size];
  return displayLabelOnly ? `${minWidth}px` : '0';
} // CSS styles related to the current size


function sizeStyles(size, wide, displayIcon, displayLabel) {
  const {
    height,
    textStyleName,
    middleSpace
  } = SIZE_STYLES[size];
  return {
    height: `${height}px`,
    middleSpace: displayIcon && displayLabel ? `${middleSpace}px` : '0',
    minWidth: getMinWidth(size, !displayIcon && displayLabel),
    padding: getPadding(size, displayIcon, displayLabel),
    textStyleCss: textStyles.textStyle(textStyleName),
    width: getWidth(size, displayIcon && !displayLabel, wide)
  };
} // CSS styles related to the current mode


function modeStyles(theme, mode, disabled) {
  if (disabled) {
    return {
      background: theme.disabled,
      color: theme.disabledContent,
      iconColor: theme.disabledContent,
      border: '0'
    };
  }

  if (mode === 'strong') {
    return {
      background: theme.accent,
      color: theme.accentContent,
      iconColor: theme.accentContent,
      border: '0'
    };
  }

  if (mode === 'positive') {
    return {
      background: theme.positive,
      color: theme.positiveContent,
      iconColor: theme.positiveContent,
      border: '0'
    };
  }

  if (mode === 'negative') {
    return {
      background: theme.negative,
      color: theme.negativeContent,
      iconColor: theme.negativeContent,
      border: '0'
    };
  }

  return {
    background: theme.surfaceInteractive,
    color: theme.surfaceContent,
    iconColor: theme.surfaceIcon,
    border: `1px solid ${theme.accent}`
  };
}

var _StyledButtonBase = _styled__default['default'](ButtonBase['default']).withConfig({
  displayName: "Button___StyledButtonBase",
  componentId: "sc-14himgq-0"
})(["display:", ";align-items:center;justify-content:center;width:", ";height:", ";min-width:", ";padding:", ";", ";font-weight:600;", ";background:", ";color:", ";white-space:nowrap;border:", ";box-shadow:", ";transition-property:transform,box-shadow;transition-duration:50ms;transition-timing-function:ease-in-out;&:active{transform:", ";box-shadow:", ";}"], p => p._css, p => p._css2, p => p._css3, p => p._css4, p => p._css5, p => p._css6, css.unselectable, p => p._css7, p => p._css8, p => p._css9, p => p._css10, p => p._css11, p => p._css12);

var _StyledSpan = _styled__default['default']("span").withConfig({
  displayName: "Button___StyledSpan",
  componentId: "sc-14himgq-1"
})(["position:relative;top:-1px;display:flex;color:", ";margin-right:", ";"], p => p._css13, p => p._css14);

function BasicButton({
  children,
  disabled,
  display,
  icon,
  iconOnly,
  innerRef,
  label,
  mode,
  size,
  wide,
  ...props
}) {
  // backward compatibility and deprecated props
  if (iconOnly) {
    environment.warnOnce('Button:iconOnly', `Button: "iconOnly" is deprecated, please use "display".`);
    display = 'icon';
  }

  if (mode === 'outline' || mode === 'secondary') {
    environment.warnOnce('Button:mode', `Button: the mode "${mode}" is deprecated, please use "normal".`);
    mode = 'normal';
  }

  if (size === 'normal' || size === 'large') {
    environment.warnOnce('Button:size', `Button: the size "${size}" is deprecated, please use "medium".`);
    size = 'medium';
  } // prop warnings


  if (display === 'icon' && !icon) {
    environment.warn(`Button: the display "icon" was used without providing an icon.`);
  }

  if (!children && !label) {
    environment.warn('Button: please provide a label.');
  }

  const theme = Theme.useTheme();

  if (display === 'auto') {
    display = 'all';
  }

  const displayIcon = icon && (display === 'all' || display === 'icon');
  const displayLabel = label && (display === 'all' || display === 'label'); // Mode styles

  const {
    background,
    color,
    iconColor,
    border
  } = React.useMemo(() => modeStyles(theme, mode, disabled), [mode, theme, disabled]); // Size styles

  const {
    height,
    middleSpace,
    minWidth,
    padding,
    textStyleCss,
    width
  } = React.useMemo(() => sizeStyles(size, wide, displayIcon, displayLabel), [size, wide, displayIcon, displayLabel]); // Use the label as a title when only the icon is displayed

  if (displayIcon && !displayLabel && label && typeof label === 'string') {
    props.title = label;
  }

  return /*#__PURE__*/React__default['default'].createElement(_StyledButtonBase, _extends._extends({
    ref: innerRef,
    focusRingSpacing: border === '0' ? 0 : 1,
    focusRingRadius: constants.RADIUS,
    disabled: disabled
  }, props, {
    _css: wide ? 'flex' : 'inline-flex',
    _css2: width,
    _css3: height,
    _css4: minWidth,
    _css5: padding,
    _css6: textStyleCss,
    _css7: background,
    _css8: color,
    _css9: border,
    _css10: disabled ? 'none' : '0 1px 3px rgba(0, 0, 0, 0.1)',
    _css11: disabled ? 'none' : 'translateY(1px)',
    _css12: disabled ? 'none' : '0px 1px 2px rgba(0, 0, 0, 0.08)'
  }), children || /*#__PURE__*/React__default['default'].createElement(React__default['default'].Fragment, null, displayIcon && /*#__PURE__*/React__default['default'].createElement(_StyledSpan, {
    _css13: iconColor,
    _css14: middleSpace
  }, icon), displayLabel && {
    label
  }));
}

BasicButton.propTypes = {
  children: index.propTypes.node,
  disabled: index.propTypes.bool,
  display: index.propTypes.oneOf(['auto', 'all', 'icon', 'label']),
  icon: index.propTypes.node,
  innerRef: index.propTypes.any,
  label: index.propTypes.string,
  mode: index.propTypes.oneOf(['normal', 'strong', 'positive', 'negative']),
  size: index.propTypes.oneOf(['medium', 'small', 'mini']),
  wide: index.propTypes.bool
};
BasicButton.defaultProps = {
  disabled: false,
  display: 'auto',
  mode: 'normal',
  size: 'medium',
  wide: false
};
const Button = /*#__PURE__*/React__default['default'].forwardRef((props, ref) => /*#__PURE__*/React__default['default'].createElement(BasicButton, _extends._extends({
  innerRef: ref
}, props)));

exports.default = Button;
//# sourceMappingURL=Button.js.map
