import _styled from 'styled-components';
import React, { useMemo } from 'react';
import { useViewport as me } from '../../../node_modules/use-viewport/dist/index.js';
import Spacer from '../Spacer/Spacer.js';
import { useTheme } from '../../theme/Theme.js';
import IconThickCross from '../../icons/components/IconThickCross.js';
import IconInfo from '../../icons/components/IconInfo.js';
import { GU, RADIUS } from '../../style/constants.js';
import { textStyle } from '../../style/text-styles.js';

function useModeColor(mode) {
  const theme = useTheme();

  if (mode === 'error') {
    return `linear-gradient(270deg, ${theme.surface} 36.46%, #3F0B0B 100%)`;
  }

  if (mode === 'warning') {
    return `linear-gradient(270deg, ${theme.surface} 36.46%, #816110 100%)`;
  }

  if (mode === 'info') {
    return `linear-gradient(270deg, ${theme.surface} 36.46%, #104A64 100%)`;
  }

  return `background: ${theme.surface}`;
}

var _StyledDiv = _styled("div").withConfig({
  displayName: "Banner___StyledDiv",
  componentId: "sc-18dlyao-0"
})(["width:100%;min-height:", ";background:", ";display:grid;grid-template-columns:", ";padding:", "px ", "px;padding-left:0;border-radius:", "px;"], p => p._css, p => p._css2, p => p._css3, p => p._css4, p => p._css5, p => p._css6);

var _StyledDiv2 = _styled("div").withConfig({
  displayName: "Banner___StyledDiv2",
  componentId: "sc-18dlyao-1"
})(["width:", "px;height:100%;display:flex;justify-content:center;align-items:center;"], p => p._css7);

var _StyledDiv3 = _styled("div").withConfig({
  displayName: "Banner___StyledDiv3",
  componentId: "sc-18dlyao-2"
})(["background:", ";width:", "px;height:", "px;border-radius:50% 50%;display:flex;justify-content:center;align-items:center;"], p => p._css8, p => p._css9, p => p._css10);

var _StyledDiv4 = _styled("div").withConfig({
  displayName: "Banner___StyledDiv4",
  componentId: "sc-18dlyao-3"
})(["width:100%;height:100%;display:flex;flex-direction:column;"]);

var _StyledH = _styled("h2").withConfig({
  displayName: "Banner___StyledH",
  componentId: "sc-18dlyao-4"
})(["", " font-weight:bold;color:", ";"], p => p._css11, p => p._css12);

var _StyledP = _styled("p").withConfig({
  displayName: "Banner___StyledP",
  componentId: "sc-18dlyao-5"
})(["", ""], p => p._css13);

function Banner({
  children,
  mode = 'info',
  title
}) {
  const modeBackground = useModeColor(mode);
  const {
    within
  } = me();
  const theme = useTheme();
  const titleColor = useMemo(() => {
    if (mode === 'error') {
      return theme.negativeSurfaceContent;
    }

    if (mode === 'info') {
      return theme.accent;
    }

    if (mode === 'warning') {
      return theme.yellow;
    }
  }, [mode, theme]);
  const modeIcon = useMemo(() => {
    if (mode === 'error') {
      return /*#__PURE__*/React.createElement(IconThickCross, {
        size: "mini"
      });
    }

    if (mode === 'info') {
      return /*#__PURE__*/React.createElement(IconInfo, {
        size: "mini"
      });
    }

    if (mode === 'warning') {
      return /*#__PURE__*/React.createElement(IconInfo, {
        size: "mini"
      });
    }
  }, [mode]);
  const compactMode = within(-1, 'medium');
  return /*#__PURE__*/React.createElement(_StyledDiv, {
    _css: 25 * GU,
    _css2: modeBackground,
    _css3: compactMode ? '1fr' : `${12 * GU}px 1fr`,
    _css4: 3 * GU,
    _css5: 4 * GU,
    _css6: RADIUS * 2
  }, !compactMode && /*#__PURE__*/React.createElement(_StyledDiv2, {
    _css7: 12 * GU
  }, /*#__PURE__*/React.createElement(_StyledDiv3, {
    _css8: titleColor,
    _css9: 4 * GU,
    _css10: 4 * GU
  }, modeIcon)), /*#__PURE__*/React.createElement(_StyledDiv4, null, /*#__PURE__*/React.createElement(_StyledH, {
    _css11: textStyle('title4'),
    _css12: titleColor
  }, title), /*#__PURE__*/React.createElement(Spacer, {
    size: 2 * GU
  }), /*#__PURE__*/React.createElement(_StyledP, {
    _css13: textStyle('body3')
  }, children)));
}

export default Banner;
//# sourceMappingURL=Banner.js.map
