import _extends from '../../../node_modules/@babel/runtime/helpers/extends.js';
import _styled from 'styled-components';
import React, { useRef, useImperativeHandle, useCallback } from 'react';
import propTypes from '../../../node_modules/prop-types/index.js';
import WrapperTextInput from '../TextInput/TextInput.js';
import ButtonIcon from '../Button/ButtonIcon.js';
import { useTheme } from '../../theme/Theme.js';
import IconCopy from '../../icons/components/IconCopy.js';
import { warn } from '../../utils/environment.js';
import { GU } from '../../style/constants.js';
import { textStyle } from '../../style/text-styles.js';
import { noop } from '../../utils/miscellaneous.js';

const HEIGHT = 5 * GU;

var _StyledDiv = _styled("div").withConfig({
  displayName: "TextCopy___StyledDiv",
  componentId: "sc-1arm9f1-0"
})(["position:relative;display:inline-flex;width:", "px;max-width:100%;height:", "px;padding-left:", ";"], p => p._css, HEIGHT, p => p._css2);

var _StyledButtonIcon = _styled(ButtonIcon).withConfig({
  displayName: "TextCopy___StyledButtonIcon",
  componentId: "sc-1arm9f1-1"
})(["width:", "px;height:", "px;border-radius:0;color:", ";"], p => p._css3, p => p._css4, p => p._css5);

var _StyledTextInput = _styled(WrapperTextInput).withConfig({
  displayName: "TextCopy___StyledTextInput",
  componentId: "sc-1arm9f1-2"
})(["text-overflow:ellipsis;height:", "px;max-width:100%;border:0px;", ";", ";&:read-only{color:", ";text-shadow:none;}"], HEIGHT, p => p._css6, p => p._css7, p => p._css8);

const TextCopy = /*#__PURE__*/React.memo( /*#__PURE__*/React.forwardRef(function TextCopy({
  adornment,
  autofocus,
  message,
  monospace,
  onCopy,
  value,
  ...props
}, ref) {
  const theme = useTheme();
  const inputRef = useRef(null); // Allows to focus the component from the outside

  useImperativeHandle(ref, () => ({
    focus: () => {
      inputRef.current.focus();
    }
  })); // Select the content on focus

  const handleFocus = useCallback(() => {
    inputRef.current && inputRef.current.select();
  }, []); // If onCopy is set (either to a function or null), Toast is not used.

  const onCopyOrToast = onCopy === undefined ? noop : onCopy || noop;
  const handleCopy = useCallback(() => {
    if (inputRef.current) {
      inputRef.current.focus();

      try {
        document.execCommand('copy');
        onCopyOrToast(message);
      } catch (err) {
        warn(err);
      }
    }
  }, [message, onCopyOrToast]);
  return /*#__PURE__*/React.createElement(_StyledDiv, _extends({}, props, {
    _css: 52.5 * GU,
    _css2: adornment ? `${HEIGHT}px` : '0'
  }), /*#__PURE__*/React.createElement(_StyledTextInput, {
    ref: inputRef,
    adornment: /*#__PURE__*/React.createElement(_StyledButtonIcon, {
      onClick: handleCopy,
      label: "Copy",
      _css3: HEIGHT - 2,
      _css4: HEIGHT - 2,
      _css5: theme.surfaceIcon
    }, adornment ?? /*#__PURE__*/React.createElement(IconCopy, null)),
    adornmentPosition: "end",
    adornmentSettings: {
      // Keep the button square
      width: HEIGHT - 2,
      padding: 0
    },
    autofocus: autofocus,
    onFocus: handleFocus,
    readOnly: true,
    value: value,
    wide: true,
    _css6: adornment ? `
                  border-top-left-radius: 0;
                  border-bottom-left-radius: 0;
                  border-left: 0;
                ` : '',
    _css7: textStyle('body3'),
    _css8: theme.surfaceContent
  }));
}));
TextCopy.propTypes = {
  adornment: propTypes.node,
  autofocus: propTypes.bool,
  message: propTypes.string,
  monospace: propTypes.bool,
  onCopy: propTypes.func,
  value: propTypes.string
};
TextCopy.defaultProps = {
  autofocus: false,
  message: 'Copied',
  monospace: true
};

export default TextCopy;
//# sourceMappingURL=TextCopy.js.map
